@@ -20,15 +20,6 @@
 
 #include "reportassistantpages_base.h"
 
-#include "drkonqi.h"
-#include "debuggermanager.h"
-#include "crashedapplication.h"
-#include "reportinterface.h"
-#include "parser/backtraceparser.h"
-#include "backtracegenerator.h"
-#include "drkonqi_globals.h"
-#include "applicationdetailsexamples.h"
-
 #include <QLabel>
 #include <QCheckBox>
 #include <QToolTip>
@@ -38,6 +29,16 @@
 #include <KUrl>
 #include <KMessageBox>
 
+#include "drkonqi.h"
+#include "debuggermanager.h"
+#include "crashedapplication.h"
+#include "reportinterface.h"
+#include "parser/backtraceparser.h"
+#include "backtracegenerator.h"
+#include "backtracewidget.h"
+#include "drkonqi_globals.h"
+#include "applicationdetailsexamples.h"
+
 //BEGIN IntroductionPage
 
 IntroductionPage::IntroductionPage(ReportAssistantDialog * parent)
@@ -138,8 +139,6 @@ BugAwarenessPage::BugAwarenessPage(ReportAssistantDialog * parent)
 
     ui.m_appSpecificDetailsExamples->setVisible(reportInterface()->appDetailsExamples()->hasExamples());
 
-    connect(ui.m_appSpecificDetailsExamples, SIGNAL(linkHovered(QString)), this,
-            SLOT(showApplicationDetailsExamples()));
     connect(ui.m_appSpecificDetailsExamples, SIGNAL(linkActivated(QString)), this,
             SLOT(showApplicationDetailsExamples()));
 }
@@ -181,7 +180,8 @@ void BugAwarenessPage::aboutToHide()
 
 void BugAwarenessPage::updateCheckBoxes()
 {
-    bool rememberSituation = ui.m_rememberCrashSituationYes->isChecked();
+    const bool rememberSituation = ui.m_rememberCrashSituationYes->isChecked();
+
     ui.m_reproducibleLabel->setEnabled(rememberSituation);
     ui.m_reproducibleBox->setEnabled(rememberSituation);
 
@@ -206,34 +206,36 @@ void BugAwarenessPage::showApplicationDetailsExamples()
 //BEGIN ConclusionPage
 
 ConclusionPage::ConclusionPage(ReportAssistantDialog * parent)
-        : ReportAssistantPage(parent),
-        needToReport(false)
+        : ReportAssistantPage(parent)
+        , m_needToReport(false)
 {
-    isBKO = DrKonqi::crashedApplication()->bugReportAddress().isKdeBugzilla();
+    m_isBKO = DrKonqi::crashedApplication()->bugReportAddress().isKdeBugzilla();
 
     ui.setupUi(this);
 
     ui.m_showReportInformationButton->setGuiItem(
-                    KGuiItem2(i18nc("@action:button", "Sho&w Contents of the Report"),
+                    KGuiItem2(i18nc("@action:button", "&Show Contents of the Report"),
                             KIcon("document-preview"),
                             i18nc("@info:tooltip", "Use this button to show the generated "
                             "report information about this crash.")));
-    connect(ui.m_showReportInformationButton, SIGNAL(clicked()), this,
-                                                                    SLOT(openReportInformation()));
+    connect(ui.m_showReportInformationButton, SIGNAL(clicked()),
+            this, SLOT(openReportInformation()));
+
     ui.m_restartAppOnFinish->setVisible(false);
 }
 
 void ConclusionPage::finishClicked()
 {
     //Manual report
-    if (needToReport && !isBKO) {
+    if (m_needToReport && !m_isBKO) {
         const CrashedApplication *crashedApp = DrKonqi::crashedApplication();
         BugReportAddress reportAddress = crashedApp->bugReportAddress();
-        QString report = reportInterface()->generateReport(false);
+        QString report = reportInterface()->generateReportFullText(false);
 
         if (reportAddress.isEmail()) {
-            QString subject = QString("Automatic crash report generated by DrKonqi for %1.")
-                                    .arg(crashedApp->name());
+            QString subject = "[%1] [%2] Automatic crash report generated by DrKonqi";
+            subject= subject.arg(crashedApp->name());
+            subject= subject.arg(crashedApp->datetime().toString("yyyy-MM-dd"));
             KToolInvocation::invokeMailer(reportAddress, "", "" , subject, report);
         } else {
             if (KUrl(reportAddress).isRelative()) { //Scheme is missing
@@ -243,13 +245,7 @@ void ConclusionPage::finishClicked()
         }
 
         //Show a copy of the bug reported
-        QString info = report + QLatin1Char('\n') +
-                            i18nc("@info/plain","Report to %1", reportAddress);
-
-        ReportInformationDialog * m_infoDialog = new ReportInformationDialog(info);
-        m_infoDialog->show();
-        m_infoDialog->raise();
-        m_infoDialog->activateWindow();
+        openReportInformation();
     }
 
     //Restart application
@@ -265,7 +261,7 @@ void ConclusionPage::aboutToShow()
     ui.m_restartAppOnFinish->setChecked(false);
 
     const bool isDuplicate = reportInterface()->duplicateId() && !reportInterface()->attachToBugNumber();
-    needToReport = reportInterface()->isWorthReporting() && !isDuplicate;
+    m_needToReport = reportInterface()->isWorthReporting() && !isDuplicate;
     emitCompleteChanged();
 
     BugReportAddress reportAddress = DrKonqi::crashedApplication()->bugReportAddress();
@@ -339,11 +335,11 @@ void ConclusionPage::aboutToShow()
     //Hide the "Show contents of the report" button if the backtrace was not generated
     ui.m_showReportInformationButton->setVisible(backtraceGenerated);
 
-    if (needToReport) {
+    if (m_needToReport) {
         ui.m_conclusionsLabel->setText(QString("<p><strong>%1</strong>").arg(i18nc("@info","This "
                                            "report is considered helpful.")));
 
-        if (isBKO) {
+        if (m_isBKO) {
             emitCompleteChanged();
             ui.m_howToProceedLabel->setText(i18nc("@info","This application's bugs are reported "
                                             "to the KDE bug tracking system: click <interface>Next"
@@ -365,7 +361,7 @@ void ConclusionPage::aboutToShow()
             emit finished(false);
         }
 
-    } else { // (needToReport)
+    } else { // (m_needToReport)
         if (!DrKonqi::crashedApplication()->hasBeenRestarted()) {
             ui.m_restartAppOnFinish->setVisible(true);
         }
@@ -382,7 +378,7 @@ void ConclusionPage::aboutToShow()
         //"manual reporting" should be ~"manual report using the contents of the report"....
         //FIXME for 4.5 (workflow, see ToDo)
         if (backtraceGenerated) {
-            if (isBKO) {
+            if (m_isBKO) {
                 ui.m_howToProceedLabel->setText(i18nc("@info","You can manually report this bug "
                                                 "at <link>%1</link>. "
                                                 "Click <interface>Finish</interface> to close the "
@@ -407,7 +403,7 @@ void ConclusionPage::aboutToHide()
 void ConclusionPage::openReportInformation()
 {
     if (!m_infoDialog) {
-        QString info = reportInterface()->generateReport(false) + QLatin1Char('\n') +
+        QString info = reportInterface()->generateReportFullText(false) + QLatin1Char('\n') +
                             i18nc("@info/plain report to url/mail address","Report to %1",
                                   DrKonqi::crashedApplication()->bugReportAddress());
 
@@ -420,7 +416,7 @@ void ConclusionPage::openReportInformation()
 
 bool ConclusionPage::isComplete()
 {
-    return (isBKO && needToReport);
+    return (m_isBKO && m_needToReport);
 }
 
 //END ConclusionPage
