@@ -17,11 +17,10 @@
    Boston, MA 02110-1301, USA.
  */
 
-#include <kaboutdata.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <KAboutData>
+#include <KApplication>
+#include <KCmdLineArgs>
+#include <KLocale>
 
 #include "knetattach.h"
 
@@ -38,7 +37,7 @@ int main(int argc, char **argv) {
 	KApplication a;
 
 	KNetAttach na;
-        a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
+        a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );
 	na.show();
 
 	return a.exec();
